@@ -1,16 +1,14 @@
 package AnyEvent::DBI::MySQL;
-
+use 5.010001;
 use warnings;
 use strict;
 use utf8;
-use feature ':5.10';
 use Carp;
 
-use version; our $VERSION = qv('1.0.6');    # REMINDER: update Changes
+our $VERSION = 'v2.0.0';
 
 ## no critic(ProhibitMultiplePackages Capitalization ProhibitNoWarnings)
 
-# REMINDER: update dependencies in Build.PL
 use base qw( DBI );
 use AnyEvent;
 use Scalar::Util qw( weaken );
@@ -266,6 +264,11 @@ __END__
 AnyEvent::DBI::MySQL - Asynchronous MySQL queries
 
 
+=head1 VERSION
+
+This document describes AnyEvent::DBI::MySQL version v2.0.0
+
+
 =head1 SYNOPSIS
 
     use AnyEvent::DBI::MySQL;
@@ -392,71 +395,68 @@ using execute_array() or execute_for_fetch().
     $dbh->tables(…)
 
 
-=head1 SUPPORT
-
-Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=AnyEvent-DBI-MySQL>.
-I will be notified, and then you'll automatically be notified of progress
-on your bug as I make changes.
-
-You can also look for information at:
-
-=over
-
-=item * RT: CPAN's request tracker
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=AnyEvent-DBI-MySQL>
-
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/AnyEvent-DBI-MySQL>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/AnyEvent-DBI-MySQL>
-
-=item * Search CPAN
-
-L<http://search.cpan.org/dist/AnyEvent-DBI-MySQL/>
-
-=back
-
-
 =head1 SEE ALSO
 
 L<AnyEvent>, L<DBI>, L<AnyEvent::DBI>
 
 
+=head1 SUPPORT
+
+=head2 Bugs / Feature Requests
+
+Please report any bugs or feature requests through the issue tracker
+at L<https://github.com/powerman/perl-AnyEvent-DBI-MySQL/issues>.
+You will be notified automatically of any progress on your issue.
+
+=head2 Source Code
+
+This is open source software. The code repository is available for
+public review and contribution under the terms of the license.
+Feel free to fork the repository and submit pull requests.
+
+L<https://github.com/powerman/perl-AnyEvent-DBI-MySQL>
+
+    git clone https://github.com/powerman/perl-AnyEvent-DBI-MySQL.git
+
+=head2 Resources
+
+=over
+
+=item * MetaCPAN Search
+
+L<https://metacpan.org/search?q=AnyEvent-DBI-MySQL>
+
+=item * CPAN Ratings
+
+L<http://cpanratings.perl.org/dist/AnyEvent-DBI-MySQL>
+
+=item * AnnoCPAN: Annotated CPAN documentation
+
+L<http://annocpan.org/dist/AnyEvent-DBI-MySQL>
+
+=item * CPAN Testers Matrix
+
+L<http://matrix.cpantesters.org/?dist=AnyEvent-DBI-MySQL>
+
+=item * CPANTS: A CPAN Testing Service (Kwalitee)
+
+L<http://cpants.cpanauthors.org/dist/AnyEvent-DBI-MySQL>
+
+=back
+
+
 =head1 AUTHOR
 
-Alex Efros  C<< <powerman@cpan.org> >>
+Alex Efros E<lt>powerman@cpan.orgE<gt>
 
 
-=head1 LICENSE AND COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2013-2014 Alex Efros <powerman@cpan.org>.
+This software is Copyright (c) 2013-2014 by Alex Efros E<lt>powerman@cpan.orgE<gt>.
 
-This program is distributed under the MIT (X11) License:
-L<http://www.opensource.org/licenses/mit-license.php>
+This is free software, licensed under:
 
-Permission is hereby granted, free of charge, to any person
-obtaining a copy of this software and associated documentation
-files (the "Software"), to deal in the Software without
-restriction, including without limitation the rights to use,
-copy, modify, merge, publish, distribute, sublicense, and/or sell
-copies of the Software, and to permit persons to whom the
-Software is furnished to do so, subject to the following
-conditions:
+  The MIT (X11) License
 
-The above copyright notice and this permission notice shall be
-included in all copies or substantial portions of the Software.
-
-THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
-EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
-OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
-NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
-FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
-OTHER DEALINGS IN THE SOFTWARE.
 
+=cut
